@@ -11,6 +11,8 @@ import requests
 import os
 from tqdm.auto import tqdm
 from shutil import rmtree
+from dotenv import load_dotenv
+import warnings
 
 from .twitter import Twitter
 from .dgl import build_dgl_dataset
@@ -19,6 +21,10 @@ from .id_updator import IdUpdator
 from .embedder import Embedder
 
 
+# Load environment variables
+load_dotenv()
+
+
 # Set up logging
 logger = logging.getLogger(__name__)
 
@@ -35,8 +41,11 @@ class MuminDataset:
     '''The MuMiN misinformation dataset, from [1].
 
     Args:
-        twitter_bearer_token (str):
-            The Twitter bearer token.
+        twitter_bearer_token (str or None, optional):
+            The Twitter bearer token. If None then the the bearer token must be
+            stored in the environment variable `TWITTER_API_KEY`, or placed in
+            a file named `.env` in the working directory, formatted as
+            "TWITTER_API_KEY=xxxxx". Defaults to None.
         size (str, optional):
             The size of the dataset. Can be either 'small', 'medium' or
             'large'. Defaults to 'small'.
@@ -93,6 +102,11 @@ class MuminDataset:
         verbose (bool): Whether extra information should be outputted.
         download_url (str): The URL to download the dataset from.
 
+    Raises:
+        ValueError:
+            If `twitter_bearer_token` is None and the environment variable
+            `TWITTER_API_KEY` is not set.
+
     References:
         - [1] Nielsen and McConville: _MuMiN: A Large-Scale Multilingual
               Multimodal Fact-Checked Misinformation Dataset with Linked Social
@@ -121,7 +135,7 @@ class MuminDataset:
     ]
 
     def __init__(self,
-                 twitter_bearer_token: str,
+                 twitter_bearer_token: Optional[str] = None,
                  size: str = 'small',
                  include_replies: bool = True,
                  include_articles: bool = True,
@@ -151,7 +165,25 @@ class MuminDataset:
         self.nodes: Dict[str, pd.DataFrame] = dict()
         self.rels: Dict[Tuple[str, str, str], pd.DataFrame] = dict()
 
-        self._twitter = Twitter(twitter_bearer_token=twitter_bearer_token)
+        # Load the bearer token if it is not provided
+        if twitter_bearer_token is None:
+            twitter_bearer_token = os.environ.get('TWITTER_API_KEY')
+
+        # If no bearer token is available, raise a warning and set the
+        # `_twitter` attribute to None. Otherwise, set the `_twitter` attribute
+        # to a `Twitter` instance.
+        if twitter_bearer_token is None:
+            warnings.warn('Twitter bearer token not provided, so '
+                          'rehydration can not be performed. This is fine '
+                          'if you are using a pre-compiled MuMiN, but if '
+                          'this is not the case then you will need to '
+                          'either specify the `twitter_bearer_token` '
+                          'argument or set the environment variable '
+                          '`TWITTER_API_KEY`.')
+            self._twitter = None
+        else:
+            self._twitter = Twitter(twitter_bearer_token=twitter_bearer_token)
+
         self._extractor = DataExtractor(
             include_replies=include_replies,
             include_articles=include_articles,
@@ -189,6 +221,11 @@ class MuminDataset:
             overwrite (bool, optional):
                 Whether the dataset directory should be overwritten, in case it
                 already exists. Defaults to False.
+
+        Raises:
+            RuntimeError:
+                If the dataset needs to be compiled and a Twitter bearer token
+                has not been provided.
         '''
         self._download(overwrite=overwrite)
         self._load_dataset()
@@ -199,6 +236,14 @@ class MuminDataset:
         # Only compile the dataset if it has not already been compiled
         if not compiled:
 
+            # If the bearer token is not available then raise an error
+            if self._twitter is None:
+                raise RuntimeError('Twitter bearer token not provided. You '
+                                   'need to either specify the '
+                                   '`twitter_bearer_token` argument in the '
+                                   '`MuminDataset` constructor or set the '
+                                   'environment variable `TWITTER_API_KEY`.')
+
             # Shrink dataset to the correct size
             self._shrink_dataset()
 
@@ -498,10 +543,9 @@ class MuminDataset:
                                 ignore_index=True)
             if ('user' in self.nodes.keys() and
                     'username' in self.nodes['user'].columns):
-                user_df = (self.nodes['user']
-                               .append(user_df)
-                               .drop_duplicates(subset='user_id')
-                               .reset_index(drop=True))
+                user_df = (pd.concat((self.nodes['user'], user_df), axis=0)
+                             .drop_duplicates(subset='user_id')
+                             .reset_index(drop=True))
             self.nodes['user'] = user_df
 
             # Add prehydration tweet features back to the tweets
@@ -524,10 +568,11 @@ class MuminDataset:
                             .reset_index(drop=True))
 
                 if 'image' in self.nodes.keys():
-                    image_df = (self.nodes['image']
-                                    .append(image_df)
-                                    .drop_duplicates(subset='media_key')
-                                    .reset_index(drop=True))
+                    image_df = (
+                        pd.concat((self.nodes['image'], image_df), axis=0)
+                          .drop_duplicates(subset='media_key')
+                          .reset_index(drop=True)
+                    )
 
                 self.nodes['image'] = image_df
 
@@ -948,12 +993,16 @@ class MuminDataset:
         Returns:
             str: The representation of the dataset.
         '''
+        bearer_token_available = (self._twitter is not None)
         if len(self.nodes) == 0 or len(self.rels) == 0:
-            return f'MuminDataset(size={self.size}, compiled={self.compiled})'
+            return (f'MuminDataset(size={self.size}, '
+                    f'compiled={self.compiled}, '
+                    f'bearer_token_available={bearer_token_available})')
         else:
             num_nodes = sum([len(df) for df in self.nodes.values()])
             num_rels = sum([len(df) for df in self.rels.values()])
             return (f'MuminDataset(num_nodes={num_nodes:,}, '
                     f'num_relations={num_rels:,}, '
                     f'size=\'{self.size}\', '
-                    f'compiled={self.compiled})')
+                    f'compiled={self.compiled}, '
+                    f'bearer_token_available={bearer_token_available})')
